@@ -5,10 +5,9 @@ from tkinter.ttk import Progressbar, Separator, Combobox
 from tkinter import filedialog as fd 
 import tkinter.font as font
 from scipy.io import loadmat, savemat, whosmat
-from scipy.io.wavfile import write as wavwrite
 from scipy.optimize import nnls
 from scipy.interpolate import interp1d
-from scipy.signal import resample
+from sklearn.cluster import KMeans
 from pygame.mixer import init, quit, get_init, set_num_channels, pre_init, music
 import matplotlib.pyplot as plt
 from matplotlib.backends.backend_tkagg import FigureCanvasTkAgg
@@ -16,8 +15,7 @@ import matplotlib.ticker as tkr
 import matplotlib.cm as cmaps # https://matplotlib.org/gallery/color/colormap_reference.html
 import numpy as np
 from numpy.matlib import repmat
-from soundfile import read # marked for deletion
-from midiutil import MIDIFile # need to move to MIDO for noteon/noteoff
+from midiutil import MIDIFile # need to move to MIDO for 
 try:
 	from pyanthem.pyanthem_vars import *
 except:
@@ -25,6 +23,7 @@ except:
 from git import Repo
 from google_drive_downloader import GoogleDriveDownloader as gdd
 import subprocess as sp
+import PIL.Image as Image
 
 def AE_download():
 	'''
@@ -48,14 +47,14 @@ def sf_download(font):
 	sf_path = os.path.join(os.path.dirname(__file__),'anthem_soundfonts')
 	if not os.path.isdir(sf_path):
 		os.mkdir(sf_path)
-	if font in soundfonts:
+	try:
 		if not os.path.isfile(os.path.join(sf_path,font+'.sf2')):
-			gdd.download_file_from_google_drive(file_id=sf_ids[soundfonts.index(font)],dest_path=os.path.join(sf_path,font+'.sf2'))
+			gdd.download_file_from_google_drive(file_id=soundfonts[font],dest_path=os.path.join(sf_path,font+'.sf2'))
 			print(f'Sound font {font} downloaded to soundfont library.')
 		else:
 			print(f'Sound font {font} already present in soundfont library.')
-	else:
-		print(f'Sound font {font} is not available font. Please choose from these: {soundfonts}')
+	except:
+		print(f'Sound font {font} is not available font. Please choose from these: {soundfonts.keys()}')
 
 def example_data_download():
 	'''
@@ -109,15 +108,22 @@ def sine_wave(hz, peak, n_samples=22000):
 	sound = np.hstack((sound[:,None],sound[:,None]))
 	return sound.astype(np.int16)
 
+def stack_videos(videos,fn='output.mp4'):
+	nvids = len(videos)
+	instr = ''
+	for i in range(len(videos)):
+		instr += ' -i '+videos[i]
+	os.system('ffmpeg -y '+instr+' -filter_complex "[0:v][1:v]hstack=inputs='+str(nvids)+'[v]; [0:a][1:a]amerge[a]" -map "[v]" -map "[a]" -ac 2 '+fn)
+
 def run(display=True):
 	'''
 	main command to run GUI or CLI
 	'''
-	print('pyanthem version {}'.format(pkg_resources.require("pyanthem")[0].version))
 	root = GUI(display=display)
 	if display:
 		root.mainloop()
 	else:
+		print('Welcome to pyanthem v{}!'.format(pkg_resources.require("pyanthem")[0].version))
 		return root
 
 class GUI(Tk):
@@ -136,7 +142,7 @@ class GUI(Tk):
 			self.default_font=font.nametofont("TkDefaultFont")
 			self.initGUI()
 	
-	def quit(self):
+	def quit(self,event=None):
 		'''
 		quits the GUI instance. currently, jupyter instances are kinda buggy
 		'''
@@ -204,7 +210,6 @@ class GUI(Tk):
 		self.brightness.set(f'{float(f"{np.max(self.data[Hstr]):.3g}"):g}')
 		self.threshold.set(f'{float(f"{np.mean(self.data[Hstr]):.3g}"):g}')
 		self.Wshow_arr = list(range(len(self.data['H'])))
-		self.status['text'] = 'Status: File load successful!'
 		self.self_to_cfg()
 		self.refresh_GUI()
 	
@@ -237,12 +242,14 @@ class GUI(Tk):
 			else:
 				return self
 
-	def refresh_GUI(self):
+	def refresh_GUI(self,event=None):
 		'''
 		
 		'''
+		self.status['text'] = 'Updating...'
+		self.update()
 		if not hasattr(self,'data'):
-			self.status['text'] = 'Status: Cannot do this - no dataset has been loaded.'
+			self.status['text'] = 'Cannot do this - no dataset has been loaded.'
 			return
 		self.process_H_W()
 		self.init_plots()
@@ -283,9 +290,12 @@ class GUI(Tk):
 		else:
 			self.Hax1.set(ylabel='Magnitude')
 
-		self.Hax1.spines['right'].set_visible(False)
+		self.Hax1.spines['left'].set_visible(False)
 		self.Hax1.spines['top'].set_visible(False)
 		self.Hax1.spines['bottom'].set_visible(False)
+		self.Hax1.spines['right'].set_visible(False)
+		self.Hax1.yaxis.tick_right()
+		self.Hax1.yaxis.set_label_position("right")
 		self.Hax1.tick_params(axis='x',which='both',bottom=False, top=False, labelbottom=False, right=False)
 
 		if len(self.Wshow_arr) > 10:
@@ -298,6 +308,12 @@ class GUI(Tk):
 		if self.offsetH.get():
 			self.Hax1.set(yticks=-yticks*Hstd,yticklabels=yticklabels)
 		self.Hax2.set(yticks=yticks,yticklabels=yticklabels)
+		self.Hax2.spines['left'].set_visible(False)
+		self.Hax2.spines['top'].set_visible(False)
+		self.Hax2.spines['bottom'].set_visible(False)
+		self.Hax2.spines['right'].set_visible(False)
+		self.Hax2.yaxis.tick_right()
+		self.Hax2.yaxis.set_label_position("right")
 		self.imWH = self.Wax1.imshow((self.data['W_pp']@np.diag(self.data['H_pp'][:,self.frameslider.get()])@self.cmap[:,:-1]*(255/self.cfg['brightness'])).reshape(self.data['W_shape'][0],self.data['W_shape'][1],3).clip(min=0,max=255).astype('uint8'))
 		self.imW = self.Wax2.imshow((self.data['W_pp']@self.cmap[:,:-1]*255/np.max(self.data['W_pp'])).reshape(self.data['W_shape'][0],self.data['W_shape'][1],3).clip(min=0,max=255).astype('uint8'))
 		
@@ -307,6 +323,7 @@ class GUI(Tk):
 		self.canvas_H.draw()
 		self.canvas_W.draw()
 		self.refresh_slider([])
+		self.status['text'] = '♫ ♪ ♫ ♪ ♫'
 
 	def process_H_W(self):
 		'''
@@ -319,7 +336,7 @@ class GUI(Tk):
 			if np.max(w) <= len(self.data['H']):
 				self.Wshow_arr = np.asarray(list(range(len(self.data['H']))))[w]
 		else:
-			self.status['text'] = 'Status: For \'components to show\', please input indices with commas and colons enclosed by square brackets, or \'all\' for all components.'
+			self.status['text'] = 'For \'components to show\', please input indices with commas and colons enclosed by square brackets, or \'all\' for all components.'
 
 		if self.display:
 			self.self_to_cfg()
@@ -333,44 +350,50 @@ class GUI(Tk):
 		# Making note matrix
 		true_fr = self.cfg['fr']*self.cfg['speed']/100
 		ns = int(len(self.data['H_pp'].T)*1000/true_fr)
-		H = resample(self.data['H_pp'], ns, axis=1) #need to change to interp1d
-		Hb = H > self.cfg['threshold']
-		Hb = Hb * 1
-		Hb[:,0] = 0
-		Hb[:,-1] = 0
-		Hmax = np.max(H)
+		t1 = np.linspace(0,len(self.data['H_pp'].T)/self.cfg['fr'],len(self.data['H_pp'].T))
+		t2 = np.linspace(0,len(self.data['H_pp'].T)/self.cfg['fr'],ns)
+		nchan = len(self.data['H_pp'])
+		Hmax = np.max(self.data['H_pp'])
 		self.data['H_fp'] = np.zeros(np.shape(self.data['H_pp']))
 		self.nd = {}
 		self.nd['st'],self.nd['en'],self.nd['note'],self.nd['mag'] = [],[],[],[]
-		for i in range(len(H)):
-			TC = np.diff(Hb[i,:])
+		for i in range(nchan):
+			H_rs = interp1d(t1,self.data['H_pp'][i,:])(t2)
+			H_b = H_rs.copy()
+			H_b[H_b<self.cfg['threshold']] = 0
+			H_b[H_b>=self.cfg['threshold']] = 1
+			H_b[0] = 0
+			H_b[-1] = 0
+			TC = np.diff(H_b)
 			st = np.argwhere(TC == 1)
 			en = np.argwhere(TC == -1)
+			bn = np.ndarray.flatten(np.argwhere(np.ndarray.flatten(en-st) < 2)).tolist()
+			st = np.ndarray.flatten(st).tolist()
+			en = np.ndarray.flatten(en).tolist()
+			for ii in sorted(bn, reverse=True):
+				st.pop(ii)
+				en.pop(ii)
+			
 			self.nd['st'].extend([x/1000 for x in st])
 			self.nd['en'].extend([x/1000 for x in en])
 			for j in range(len(st)):
-				tmpmag = np.max(H[i,st[j][0]:en[j][0]])
-				self.data['H_fp'][i,int(st[j][0]*true_fr/1000):int(en[j][0]*true_fr/1000)] = tmpmag
-				self.nd['mag'].append(int(tmpmag * 127 / Hmax))
+				mag = np.max(H_rs[st[j]:en[j]])
+				self.data['H_fp'][i,int(st[j]*true_fr/1000):int(en[j]*true_fr/1000)] = mag
+				self.nd['mag'].append(int(mag * 127 / Hmax))
 				self.nd['note'].append(self.keys[i])
-
+			self.data['H_pp'][self.data['H_pp'] < 0] = 0
 		# Colormap
 		if hasattr(cmaps,self.cfg['cmapchoice']):
 			cmap = getattr(cmaps,self.cfg['cmapchoice'])
 			self.cmap = cmap(np.linspace(0,1,len(self.data['H_pp'])))
 		else:
-			self.status['text'] = f'Status: cmap {self.cfg["cmapchoice"]} not found. Please check the matplotlib documentation for a list of standard colormaps.'
+			self.status['text'] = f'cmap {self.cfg["cmapchoice"]} not found. Please check the matplotlib documentation for a list of standard colormaps.'
 
 	def make_keys(self):
 		'''
 		
 		'''
-		scaledata = []
 		nnotes = len(self.data['H_pp'])
-		with open(os.path.join(self.package_path,'scaledata.csv')) as csvfile:
-			file = csv.reader(csvfile)
-			for row in file:
-				scaledata.append([int(x) for x in row if x != 'NaN'])
 		noteIDX = scaledata[scale_type_opts.index(self.cfg['scale_type'])]
 		noteIDX = [k+key_opts.index(self.cfg['key']) for k in noteIDX]
 		keys = []
@@ -384,17 +407,15 @@ class GUI(Tk):
 		
 		'''
 		if not hasattr(self,'data'):
-			self.status['text'] = 'Status: Cannot do this - no dataset has been loaded.'
+			self.status['text'] = 'Cannot do this - no dataset has been loaded.'
 			return
-		if hasattr(self,'imWH'):
-			self.imWH.remove()
-		self.imWH = self.Wax1.imshow((self.data['W_pp']@np.diag(self.data['H_pp'][:,self.frameslider.get()])@self.cmap[:,:-1]*(255/self.cfg['brightness'])).reshape(self.data['W_shape'][0],self.data['W_shape'][1],3).clip(min=0,max=255).astype('uint8'))
-		if not hasattr(self,'H_vline'):
-			self.H_vline, = self.Hax1.plot([],'k',linewidth=.5)
-		self.H_vline.set_xdata([self.frameslider.get(), self.frameslider.get()])
-		self.H_vline.set_ydata(self.Hax1.get_ylim())
+		self.imWH.set_data((self.data['W_pp']@np.diag(self.data['H_pp'][:,self.frameslider.get()])@self.cmap[:,:-1]*(255/self.cfg['brightness'])).reshape(self.data['W_shape'][0],self.data['W_shape'][1],3).clip(min=0,max=255).astype('uint8'))
 		self.canvas_W.draw()
-		self.canvas_H.draw()
+		# if not hasattr(self,'H_vline'):
+		# 	self.H_vline, = self.Hax1.plot([],'k',linewidth=.5)
+		# self.H_vline.set_xdata([self.frameslider.get(), self.frameslider.get()])
+		# self.H_vline.set_ydata(self.Hax1.get_ylim())
+		# self.canvas_H.draw()
 
 	def preview_notes(self):
 		'''
@@ -406,7 +427,7 @@ class GUI(Tk):
 			fn_midi = os.path.join(self.package_path,'preview.mid')
 			fn_wav = os.path.join(self.package_path,'preview.wav')
 			if not hasattr(self,'data'):
-				self.status['text'] = 'Status: Cannot do this - no dataset has been loaded.'
+				self.status['text'] = 'Cannot do this - no dataset has been loaded.'
 				return
 			if get_init() is None: # Checks if pygame has initialized audio engine. Only needs to be run once per instance
 				pre_init(44100, -16, 2, 1024)
@@ -445,18 +466,20 @@ class GUI(Tk):
 			if not self.display:
 				self.process_H_W()
 			self.make_keys() # Just in case
+			print(self.keys)
 			if self.display:
 				self.dump_config()
 			if self.cfg['audio_format'] == 'MIDI' or self.cfg['audio_format'].endswith('.sf2'):
 				fn_midi = os.path.join(self.cfg['save_path'],self.cfg['file_out'])+'.mid'
 				fn_wav = os.path.join(self.cfg['save_path'],self.cfg['file_out'])+'.wav'
-				MIDI = MIDIFile(1)  # One track
+				MIDI = MIDIFile(2)  # One track
 				MIDI.addTempo(0,0,60) # addTempo(track, time, tempo)
+				print(self.keys)
 				for j in range(len(self.nd['note'])):
 					# addNote(track, channel, pitch, time + i, duration, volume)
 					MIDI.addNote(0, 0, self.nd['note'][j], self.nd['st'][j], (self.nd['en'][j]-self.nd['st'][j]), self.nd['mag'][j])
 				with open(fn_midi, 'wb') as mid:
-					MIDI.writeFile(mid)		
+					MIDI.writeFile(mid)
 			if self.cfg['audio_format'].endswith('.sf2'):
 				fn_font = os.path.join(self.package_path,'anthem_soundfonts',self.cfg['audio_format'])
 				os.system('fluidsynth -ni -F {} -r 44100 {} {}'.format(fn_wav,fn_font,fn_midi))
@@ -464,84 +487,15 @@ class GUI(Tk):
 				self.synth()
 			elif self.cfg['audio_format'] == 'Stream':
 				self.neuralstream()
-			if not self.display:
-				return
-	
-	def synth(self):
-		'''
-		
-		'''
-		fs = 44100
-		r = .5 # release for note
-		#r_mat = np.linspace(1, 0, num=int(fs*r))
-		#r_mat = np.vstack((r_mat,r_mat)).T
-		currnote = -1
-		ext = 11
-		note = [[0] * 8 for i in range(3)]
-		raws = np.zeros((int(fs*(np.max(self.nd['st'])+ext)),2))
-		nnotes = len(self.nd['st'])
-		for i in range(len(self.nd['st'])):
-			if currnote != self.nd['note'][i]:
-				currnote = self.nd['note'][i]
-				for mag in range(8): # Load up new notes
-					for length in range(3):
-						fn = str(currnote+1)+'_'+str(mag)+'_'+str(length+1)+'.ogg';
-						note[length][mag],notused = read(os.path.join(self.package_path,'AE',fn))
-			L = self.nd['en'][i]-self.nd['st'][i]
-			L = min(L,10-r)
-			if L > 1:
-				raw = note[2][int(np.ceil(self.nd['mag'][i]/16-1))]#[0:int(L*fs)] # Truncate to note length plus release
-			elif 1 > L > .25:
-				raw = note[1][int(np.ceil(self.nd['mag'][i]/16-1))]#[0:int(L*fs)] # Truncate to note length plus release
-			elif L < .25:
-				raw = note[0][int(np.ceil(self.nd['mag'][i]/16-1))]#[0:int(L*fs)] # Truncate to note length plus release
-			#raw[-int(fs*r):] *= r_mat
-			inds = range(int(self.nd['st'][i][0]*fs),int(self.nd['st'][i][0]*fs)+len(raw))
-			raws[inds,:] += raw
 			if self.display:
-				self.status['text'] = f'Status: writing audio file, {i+1} out of {nnotes} notes written'
-				self.update()
-		raws = raws[:-fs*(ext-1),:] # Crop wav
-		raws = np.int16(raws/np.max(np.abs(raws)) * 32767)
-		wavwrite(os.path.join(self.cfg['save_path'],self.cfg['file_out'])+'.wav',fs,raws)
-		if self.display:
-			self.status['text'] = f'Status: audio file written to {self.cfg["save_path"]}'
-
-	def neuralstream(self):
-		'''
-		
-		'''
-		C0 = 16.352
-		fs = 44100
-		freqs = [C0*2**(i/12) for i in range(128)]
-		true_fr = (self.cfg['fr']*self.cfg['speed'])/100
-		ns = int(fs*len(self.data['H_fp'].T)/true_fr)
-		t1 = np.linspace(0,len(self.data['H_fp'].T)/self.cfg['fr'],len(self.data['H_fp'].T))
-		t2 = np.linspace(0,len(self.data['H_fp'].T)/self.cfg['fr'],ns)
-		H = np.zeros((len(t2),))
-		nchan = len(self.data['H_fp'])
-		for n in range(nchan):
-			Htmp = self.data['H_fp'][n,:]
-			Htmp[Htmp<0] = 0
-			Htmp = interp1d(t1,Htmp)(t2)
-			H += np.sin(2*np.pi*freqs[self.keys[n]]*t2)*Htmp
-			Hstr = 'H_fp'
-			if self.display:
-				self.status['text'] = f'Status: Writing audio: {n+1} out of {nchan} channels...'
-				self.update()
-		wav = np.hstack((H[:,None],H[:,None]))
-		wav = np.int16(wav/np.max(np.abs(wav)) * 32767)
-		wavwrite(os.path.join(self.cfg['save_path'],self.cfg['file_out'])+'.wav',fs,wav)
-		if self.display:
-			self.status['text'] = f'Status: audio file written to {self.cfg["save_path"]}'
-		else:
-			print(f'Audio file written to {self.cfg["save_path"]}')
+				self.status['text'] = f'Audio file written to {self.cfg["save_path"]}'
+			else:
+				print(f'Audio file written to {self.cfg["save_path"]}')
 
 	def write_video(self):
 		'''
 		Writes video file using self.data['H_pp'] using opencv
 		'''
-		import PIL.Image as Image
 		if self.check_data_and_save_path():		
 			if not self.display:
 				self.process_H_W()
@@ -550,14 +504,15 @@ class GUI(Tk):
 			fn_vid = os.path.join(self.cfg['save_path'],self.cfg['file_out'])+'.mp4'
 			v_shape = self.data['W_shape'][::-1][1:]
 			command = [ 'ffmpeg',
+				'-loglevel', 'error',
 				'-y',
-				'-f', 'rawvideo',
-				'-vcodec','mjpeg',
+				'-f', 'image2pipe',
+				'-vcodec','png',
 				'-s', '{}x{}'.format(v_shape[0],v_shape[1]),
-				'-pix_fmt', 'rgb24',
-				'-r', str(self.cfg['fr']),
+				'-r', str(self.cfg['fr']*self.cfg['speed']/100),
 				'-i', '-', # The input comes from a pipe
 				'-an', # Tells FFMPEG not to expect any audio
+				'-q:v','2',
 				'-vcodec', 'mpeg4',
 				fn_vid]
 			pipe = sp.Popen( command, stdin=sp.PIPE, stderr=sp.PIPE)
@@ -565,25 +520,14 @@ class GUI(Tk):
 			for i in range(nframes):
 				frame = (self.data['W_pp']@np.diag(self.data['H_pp'][:,i])@self.cmap[:,:-1]*(255/self.cfg['brightness'])).reshape(self.data['W_shape'][0],self.data['W_shape'][1],3).clip(min=0,max=255).astype('uint8')
 				im = Image.fromarray(frame)
-				im.save(pipe.stdin, 'JPEG')
-				pipe.stdin.write(frame.tostring())
+				im.save(pipe.stdin, 'PNG')
 				if self.display and i%10==0:
-					self.status['text'] = f'Status: writing video file, {i} out of {nframes} frames written'
+					self.status['text'] = f'Writing video file, {i} out of {nframes} frames written'
 					self.update()
 			pipe.stdin.close()
 			pipe.wait()
-			#fourcc = cv2.VideoWriter_fourcc(*'mp4v')
-			#out = cv2.VideoWriter(, fourcc, self.cfg['fr']*self.cfg['speed']/100, tuple(self.data['W_shape'][::-1][1:]),True)
-			#
-			#for i in range(nframes):
-			#	frame = (self.data['W_pp']@np.diag(self.data['H_pp'][:,i])@self.cmap[:,:-1]*(255/self.cfg['brightness'])).reshape(self.data['W_shape'][0],self.data['W_shape'][1],3).clip(min=0,max=255).astype('uint8')
-			#	out.write(cv2.cvtColor(frame, cv2.COLOR_RGB2BGR))
-			#	if self.display:
-			#		self.status['text'] = f'Status: writing video file, {i+1} out of {nframes} frames written'
-			#		self.update()
-			#out.release()
 			if self.display:
-				self.status['text'] = f'Status: video file written to {self.cfg["save_path"]}'
+				self.status['text'] = f'video file written to {self.cfg["save_path"]}'
 			else:
 				print(f'Video file written to {self.cfg["save_path"]}')
 				return self
@@ -597,7 +541,7 @@ class GUI(Tk):
 			cmd = 'ffmpeg -hide_banner -loglevel warning -y -i {} -i {} -c:v copy -c:a aac {}'.format(fn+'.mp4',fn+'.wav',fn+'_AV.mp4')
 			os.system(cmd)
 			if self.display:
-				self.status['text'] = f'Status: Video file w/ audio written to {self.cfg["save_path"]}'
+				self.status['text'] = f'Video file w/ audio written to {self.cfg["save_path"]}'
 			else:
 				print(f'A/V file written to {self.cfg["save_path"]}')
 				return self
@@ -620,10 +564,18 @@ class GUI(Tk):
 		fn = os.path.join(self.cfg['save_path'],self.cfg['file_out'])
 		try:
 			os.remove(fn+'.mp4')
+		except OSError: 
+			pass
+		try:
 			os.remove(fn+'.wav')
-		except: pass
+		except OSError: 
+			pass
+		try:
+			os.remove(fn+'.mid')
+		except OSError: 
+			pass
 		if self.display:
-			self.status['text'] = f'A/V only videos removed'
+			self.status['text'] = '.wav, .mid, .mp4 (silent) videos removed'
 		else:
 			print(f'A/V only videos removed')
 			return self
@@ -635,7 +587,8 @@ class GUI(Tk):
 		'''
 		
 		'''
-		self.winfo_toplevel().title("pyanthem GUI")
+
+		self.winfo_toplevel().title('pyanthem v{}'.format(pkg_resources.require("pyanthem")[0].version))
 		self.protocol("WM_DELETE_WINDOW", self.quit)
 
 		# StringVars
@@ -654,49 +607,50 @@ class GUI(Tk):
 		self.key=init_entry('C')
 		self.audio_format=init_entry('Stream')
 		self.Wshow=init_entry('all')
-		self.status=init_entry('Status: Welcome to pyanthem!')
 		self.cmapchoice=init_entry('jet')
 		
 		# Labels
-		Label(text='').grid(row=0,column=0) # Just to give a border around Seperators
-		Label(text='File Parameters',font='Helvetica 14 bold').grid(row=0,column=1,columnspan=2,sticky='WE')
-		Label(text='Movie Parameters',font='Helvetica 14 bold').grid(row=0,column=3,columnspan=2,sticky='WE')
-		Label(text='Audio Parameters',font='Helvetica 14 bold').grid(row=0,column=5,columnspan=2,sticky='WE')
-		Label(text='Input Filename').grid(row=1, column=1,columnspan=2,sticky='W')
-		Label(text='Output Filename').grid(row=3, column=1,columnspan=2,sticky='W')
-		Label(text='Save Path').grid(row=5, column=1,columnspan=1,sticky='W')
-		Label(text='Playback speed (%)').grid(row=1, column=3, sticky='E')
-		Label(text='Start (%)').grid(row=2, column=3, sticky='E')
-		Label(text='End (%)').grid(row=3, column=3, sticky='E')
-		Label(text='Baseline').grid(row=4, column=3, sticky='E')
-		Label(text='Max brightness').grid(row=5, column=3, sticky='E')
-		Label(text='Colormap').grid(row=6, column=3, sticky='E')
-		Label(text='Threshold').grid(row=1, column=5, sticky='E')
-		Label(text='Octave').grid(row=2, column=5, sticky='E')
-		Label(text='Scale Type').grid(row=3, column=5, sticky='E')
-		Label(text='Key').grid(row=4, column=5, sticky='E')
-		Label(text='Audio format').grid(row=5, column=5, sticky='E')
+		Label(text='',font='Helvetica 1 bold').grid(row=0,column=0) # Just to give a border around Seperators
+		Label(text='File Parameters',font='Helvetica 14 bold').grid(row=1,column=1,columnspan=2,sticky='WE')
+		Label(text='Movie Parameters',font='Helvetica 14 bold').grid(row=1,column=3,columnspan=2,sticky='WE')
+		Label(text='Audio Parameters',font='Helvetica 14 bold').grid(row=1,column=5,columnspan=2,sticky='WE')
+		Label(text='Input Filename').grid(row=2, column=1,columnspan=2,sticky='W')
+		Label(text='Output Filename').grid(row=4, column=1,columnspan=2,sticky='W')
+		Label(text='Save Path').grid(row=6, column=1,columnspan=1,sticky='W')
+		Label(text='Speed (%)').grid(row=2, column=3, sticky='E')
+		Label(text='Start (%)').grid(row=3, column=3, sticky='E')
+		Label(text='End (%)').grid(row=4, column=3, sticky='E')
+		Label(text='Baseline').grid(row=5, column=3, sticky='E')
+		Label(text='Max brightness').grid(row=6, column=3, sticky='E')
+		Label(text='Colormap').grid(row=7, column=3, sticky='E')
+		Label(text='Threshold').grid(row=2, column=5, sticky='E')
+		Label(text='Octave').grid(row=3, column=5, sticky='E')
+		Label(text='Scale Type').grid(row=4, column=5, sticky='E')
+		Label(text='Key').grid(row=5, column=5, sticky='E')
+		Label(text='Audio format').grid(row=6, column=5, sticky='E')
+		#Message(text='Status',font='Helvetica 14 bold').grid(row=9, column=2)
 
 		# Messages
-		self.status = Message(text='Status: Welcome to pyanthem!',aspect=1000)
-		self.status.grid(row=8, column=1,columnspan=4,sticky='W')
+		self.status = Message(text='> Welcome to pyanthem v{}'.format(pkg_resources.require("pyanthem")[0].version),aspect=1000,bg='white',fg='black')
+		self.status.grid(row=9, column=2,columnspan=5,sticky='NESW')
+		self.status['anchor']='w'
 		self.status.grid_propagate(0)
 
 		# Entries
-		Entry(textvariable=self.file_in).grid(row=2, column=1,columnspan=2,sticky='W')
-		Entry(textvariable=self.file_out).grid(row=4, column=1,columnspan=2,sticky='W')
-		Entry(textvariable=self.save_path,width=17).grid(row=6, column=1,columnspan=2,sticky='EW')
-		Entry(textvariable=self.speed,width=7).grid(row=1, column=4, sticky='W')
-		Entry(textvariable=self.st_p,width=7).grid(row=2, column=4, sticky='W')
-		Entry(textvariable=self.en_p,width=7).grid(row=3, column=4, sticky='W')
-		Entry(textvariable=self.baseline,width=7).grid(row=4, column=4, sticky='W')
-		Entry(textvariable=self.brightness,width=7).grid(row=5, column=4, sticky='W')
-		Entry(textvariable=self.threshold,width=7).grid(row=1, column=6, sticky='W')
+		Entry(textvariable=self.file_in).grid(row=3, column=1,columnspan=2,sticky='W')
+		Entry(textvariable=self.file_out).grid(row=5, column=1,columnspan=2,sticky='W')
+		Entry(textvariable=self.save_path,width=17).grid(row=7, column=1,columnspan=2,sticky='EW')
+		Entry(textvariable=self.speed,width=7).grid(row=2, column=4, sticky='W')
+		Entry(textvariable=self.st_p,width=7).grid(row=3, column=4, sticky='W')
+		Entry(textvariable=self.en_p,width=7).grid(row=4, column=4, sticky='W')
+		Entry(textvariable=self.baseline,width=7).grid(row=5, column=4, sticky='W')
+		Entry(textvariable=self.brightness,width=7).grid(row=6, column=4, sticky='W')
+		Entry(textvariable=self.threshold,width=7).grid(row=2, column=6, sticky='W')
 
 		# Buttons
-		Button(text='Edit',command=self.edit_save_path,width=5).grid(row=5, column=2)
-		Button(text='Preview Notes',width=15,command=self.preview_notes).grid(row=6, column=5,columnspan=2)
-		Button(text='Update',width=15,command=self.refresh_GUI).grid(row=8, column=5,columnspan=2)
+		Button(text='Edit',command=self.edit_save_path,width=5).grid(row=6, column=2)
+		Button(text='Preview Notes',width=11,command=self.preview_notes).grid(row=7, column=5,columnspan=2)
+		Button(text='Update',width=7,font='Helvetica 14 bold',command=self.refresh_GUI).grid(row=9, column=1,columnspan=1)
 
 		# Option/combobox values
 		audio_format_opts = ['Stream']
@@ -708,31 +662,32 @@ class GUI(Tk):
 		# Option Menus
 		oct_add_menu = OptionMenu(self,self.oct_add,*oct_add_opts)
 		oct_add_menu.config(width=7)
-		oct_add_menu.grid(row=2, column=6, sticky='W')
+		oct_add_menu.grid(row=3, column=6, sticky='W')
 		scale_type_menu=OptionMenu(self,self.scale_type,*scale_type_opts)
 		scale_type_menu.config(width=7)
 		scale_type_menu.config(font=(self.default_font,(8)))
-		scale_type_menu.grid(row=3, column=6, sticky='EW')
+		scale_type_menu.grid(row=4, column=6, sticky='EW')
 		key_menu=OptionMenu(self,self.key,*key_opts)
 		key_menu.config(width=7)
-		key_menu.grid(row=4, column=6, sticky='W')
+		key_menu.grid(row=5, column=6, sticky='W')
 		audio_format_menu=OptionMenu(self,self.audio_format,*audio_format_opts)
 		audio_format_menu.config(width=7)
-		audio_format_menu.grid(row=5, column=6, sticky='W')
+		audio_format_menu.grid(row=6, column=6, sticky='W')
 		
 		# Combo box
 		self.cmapchooser = Combobox(self,textvariable=self.cmapchoice,width=7)
 		self.cmapchooser['values'] = cmaps_opts
 		#self.cmapchooser['state'] = 'readonly'
-		self.cmapchooser.grid(row=6, column=4, sticky='WE')
+		self.cmapchooser.grid(row=7, column=4, sticky='WE')
 		self.cmapchooser.current()
 		self.cmap = []
+
 		# Menu bar
 		menubar=Menu(self)
 		filemenu=Menu(menubar, tearoff=0)
 		filemenu.add_command(label="Load from .mat", command=self.load_GUI)
 		filemenu.add_command(label="Load .cfg", command=self.load_config)
-		filemenu.add_command(label="Quit",command=self.quit)
+		filemenu.add_command(label="Quit",command=self.quit,accelerator="Ctrl+Q")
 
 		savemenu=Menu(menubar, tearoff=0)
 		savemenu.add_command(label="Audio", command=self.write_audio)
@@ -746,8 +701,8 @@ class GUI(Tk):
 		self.config(menu=menubar)
 
 		# Seperators
-		s_v=[[0,0,9],[2,0,8],[4,0,8],[6,0,9]]
-		s_h=[[1,0,6],[1,1,6],[1,8,6],[1,9,6],[1,3,2],[1,5,2]]
+		s_v=[[0,1,9],[2,1,8],[4,1,8],[6,1,9]]
+		s_h=[[1,1,6],[1,2,6],[1,9,6],[1,10,6],[1,4,2],[1,6,2]]
 		for sv in s_v:
 			Separator(self, orient='vertical').grid(column=sv[0], row=sv[1], rowspan=sv[2], sticky='nse')
 		for sh in s_h:
@@ -760,6 +715,11 @@ class GUI(Tk):
 		# frameslider
 		self.frameslider=Scale(self, from_=0, to=1, orient=HORIZONTAL)
 		self.frameslider['command']=self.refresh_slider
+		self.update()
+
+		# Bind shortcuts
+		self.bind_all("<Control-q>", self.quit)
+		self.bind_all("<Control-a>", self.refresh_GUI)
 
 	def init_plots(self):
 		'''
@@ -769,42 +729,41 @@ class GUI(Tk):
 		self.figH = plt.Figure(figsize=(6,6), dpi=100, tight_layout=True)
 		self.Hax1 = self.figH.add_subplot(211)
 		self.Hax2 = self.figH.add_subplot(212)
-		self.Hax1.set_title('Raw Temporal Data (H)')
-		self.Hax2.set_title('Converted Temporal Data (H\')')
+		self.Hax1.set_title('Temporal Data (H)')
+		self.Hax2.set_title('Audio Preview (H\')')
 		self.canvas_H = FigureCanvasTkAgg(self.figH, master=self)
-		self.canvas_H.get_tk_widget().grid(row=0,column=7,rowspan=29,columnspan=10)
-		bg = self.status.winfo_rgb(self.status['bg'])
+		self.canvas_H.get_tk_widget().grid(row=1,column=7,rowspan=29,columnspan=10)
+		bg = self.status.winfo_rgb(self['bg'])
 		self.figH.set_facecolor([(x>>8)/255 for x in bg])
 		self.canvas_H.draw()
 
 		# Checkbox
-		Checkbutton(self, text="Offset H",command=self.refresh_GUI,variable=self.offsetH).grid(row=0,rowspan=1,column=16)
+		Checkbutton(self, text="Offset H",command=self.refresh_GUI,variable=self.offsetH).grid(row=1,rowspan=1,column=16)
 
 		# W
 		self.figW = plt.Figure(figsize=(6,3), dpi=100, constrained_layout=True)
 		self.Wax1 = self.figW.add_subplot(121)
 		self.Wax2 = self.figW.add_subplot(122)
-		self.Wax1.set_title('Output(H x W)')
-		self.Wax2.set_title('Spatial Components (W)')
+		self.Wax1.set_title('Video Preview')
+		self.Wax2.set_title('Spatial Data (W)')
 		self.Wax1.axis('off')
 		self.Wax2.axis('off')
 		self.canvas_W = FigureCanvasTkAgg(self.figW, master=self)
-		self.canvas_W.get_tk_widget().grid(row=10,column=1,rowspan=19,columnspan=6)
+		self.canvas_W.get_tk_widget().grid(row=11,column=1,rowspan=19,columnspan=6)
 		self.figW.set_facecolor([(x>>8)/255 for x in bg])
 		self.canvas_W.draw()
 		
 		# Frameslider
-		self.frameslider.grid(row=29, column=2, columnspan=1)
+		self.frameslider.grid(row=30, column=1, columnspan=3,sticky='EW')
 
 		# Wshow
-		Label(text='Components to show:').grid(row=29, column=3, columnspan=3, sticky='E')
-		Entry(textvariable=self.Wshow,width=15,justify='center').grid(row=29, column=5, columnspan=2,sticky='E')
+		Label(text='Components to show:').grid(row=30, column=3, columnspan=3, sticky='E')
+		Entry(textvariable=self.Wshow,width=15,justify='center').grid(row=30, column=5, columnspan=2,sticky='E')
 
 	def process_raw(self,file_in=None,n_clusters=None,frame_rate=None,save=False):
 		'''
 		
 		'''
-		from sklearn.cluster import KMeans
 		if file_in is None:
 			root = Tk()
 			root.withdraw()
