@@ -25,6 +25,28 @@ scale_type_opts = ['Chromatic (12/oct)','Major scale (7/oct)','Minor scale (7/oc
 'Dim. triad (3/oct)','Maj. 6th (4/oct)','Min. 6th (4/oct)',
 'Maj. 7th (4/oct)','Min. 7th (4/oct)','Aug. 7th (4/oct)',
 'Dim. 7th (4/oct)','Maj. 7/9 (5/oct)','Min. 7/9 (5/oct)']
+
+scaledata = [
+[0,1,2,3,4,5,6,7,8,9,10,11],
+[0,2,4,5,7,9,11],
+[0,2,3,5,7,9,11],
+[0,4,7],
+[0,3,7],
+[0,4,8],
+[0,3,6],
+[0,4,7,9 ],
+[0,3,7,9 ],
+[0,4,7,11],
+[0,3,7,11],
+[0,3,7,10],
+[0,4,8,10],
+[0,3,6,9 ],
+[0,3,6,10],
+[0,3,7,11],
+[0,2,4,7,9,11],
+[0,2,3,7,9,11]
+]
+
 key_opts = ['C','C#/D♭','D','D#/E♭','E','F','F#/G♭','G','G#/A♭','A','A#/B♭','B']
 
 cmaps_opts = tuple(sorted(['viridis', 'plasma', 'inferno', 'magma', 'cividis','binary', 
@@ -37,10 +59,13 @@ example_files_decomp = [join(pth,'anthem_datasets',d) for d in ['demo1.mat','dem
 example_files_raw = [join(pth,'anthem_datasets',d) for d in ['raw1.mat','raw2.mat']]
 example_cfg = [join(pth,'anthem_datasets',d) for d in ['demo1_cfg.p','demo2_cfg.p','demo3_cfg.p','demo4_cfg.p']]
 
-soundfonts=['piano_small','piano_large','e-piano','strings']
-sf_ids=[
-		'12WYF3pc_kYI5myMjgEUnb-y2CeX3fucx',
-		'1DEKLuSiJ4QsHdipfzQdKGsmFn5_4ipOL',
-		'0B4_6p-MMrzwLeTBfNzl1SmVVSEU',
-		'1c0pCI0YdcFEpSLEbCW8HTzFOlJpz0HS9'
-]
\ No newline at end of file
+soundfonts={
+'piano_small':'12WYF3pc_kYI5myMjgEUnb-y2CeX3fucx',
+'piano_large':'1DEKLuSiJ4QsHdipfzQdKGsmFn5_4ipOL',
+'e-piano':'0B4_6p-MMrzwLeTBfNzl1SmVVSEU',
+'strings':'1c0pCI0YdcFEpSLEbCW8HTzFOlJpz0HS9'
+}
+
+
+
+
